from setuptools import setup

setup(name='distributions_statistics_v2',
      version='0.2',
      description='Gaussian distributions',
      packages=['distributions_statistics_v2'],
      author='sneha',
      author_email='snehaoladri96@gmail.com',
      zip_safe=False)
